MarginRankingLoss
=================

.. currentmodule:: pykeen.losses

.. autoclass:: MarginRankingLoss
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~MarginRankingLoss.hpo_default
      ~MarginRankingLoss.synonyms

   .. rubric:: Methods Summary

   .. autosummary::

      ~MarginRankingLoss.forward
      ~MarginRankingLoss.process_lcwa_scores
      ~MarginRankingLoss.process_slcwa_scores

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: synonyms

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: process_lcwa_scores
   .. automethod:: process_slcwa_scores
